@@ -5,16 +5,16 @@ from dotenv.main import dotenv_values
 @dataclass
 class ConfigData:
     drafts: bool = False
-    blog_title: str = 'My Blog'
-    dest_dir: str = '.build'
-    source_dir: str = '.blog'
-    posts_dir: str = 'Posts'
-    pages_dir: str = 'Pages'
-    layouts_dir: str = '.blog/_layouts'
-    assets_dir: str = '.blog/_assets'
-    assets_dest_dir: str = '.build/static'
-    public_dir: str = '/static'
-    default_layout: str = 'main'
+    blog_title: str = "My Blog"
+    dest_dir: str = ".build"
+    source_dir: str = ".blog"
+    posts_dir: str = "Posts"
+    pages_dir: str = "Pages"
+    layouts_dir: str = ".blog/_layouts"
+    assets_dir: str = ".blog/_assets"
+    assets_dest_dir: str = ".build/static"
+    public_dir: str = "/static"
+    default_layout: str = "main"
     port: int = 4200
 
     def override(self, config: dict):
@@ -24,7 +24,7 @@ class ConfigData:
                 setattr(self, i.name, config[i.name])
 
     def load_dotenv(self):
-        self.override(dotenv_values('.env'))
+        self.override(dotenv_values(".env"))
 
 
 config = ConfigData()
